@@ -51,8 +51,9 @@ void usage(char const *prg) {
 		"use: %s --diff [-C N]   from-file  to-file\n"
 		"     %s --patch         orig-file  patch-file\n"
 		"     %s --bdiff [-B N]  from-file  to-file\n"
+		"     %s --rabdiff       from-file  to-file\n"
 		"     %s --bpatch        orig-file  patch-file\n",
-		prg, prg, prg, prg);
+		prg, prg, prg, prg, prg);
 }
 
 
@@ -75,7 +76,7 @@ static void *wrap_realloc(void *priv, void *ptr, unsigned int size) {
 
 
 int main(int argc, char *argv[]) {
-	int i = 1, ctxlen = 3, bsize = 16, do_diff, do_patch, do_bdiff, do_bpatch;
+	int i = 1, ctxlen = 3, bsize = 16, do_diff, do_patch, do_bdiff, do_bpatch, do_rabdiff;
 	memallocator_t malt;
 	mmfile_t mf1, mf2;
 	xpparam_t xpp;
@@ -93,7 +94,7 @@ int main(int argc, char *argv[]) {
 	malt.realloc = wrap_realloc;
 	xdl_set_allocator(&malt);
 
-	do_diff = do_patch = do_bdiff = do_bpatch = 0;
+	do_diff = do_patch = do_bdiff = do_bpatch = do_rabdiff = 0;
 	if (!strcmp(argv[i], "--diff")) {
 		i++;
 		do_diff = 1;
@@ -117,6 +118,9 @@ int main(int argc, char *argv[]) {
 			} else
 				break;
 		}
+	} else if (!strcmp(argv[i], "--rabdiff")) {
+		i++;
+		do_rabdiff = 1;
 	} else if (!strcmp(argv[i], "--bpatch")) {
 		i++;
 		do_bpatch = 1;
@@ -156,6 +160,15 @@ int main(int argc, char *argv[]) {
 		ecb.outf = xdlt_outf;
 		if (xdl_bdiff(&mf1, &mf2, &bdp, &ecb) < 0) {
 
+			xdl_free_mmfile(&mf2);
+			xdl_free_mmfile(&mf1);
+			return 4;
+		}
+	} else if (do_rabdiff) {
+		ecb.priv = stdout;
+		ecb.outf = xdlt_outf;
+		if (xdl_rabdiff(&mf1, &mf2, &ecb) < 0) {
+
 			xdl_free_mmfile(&mf2);
 			xdl_free_mmfile(&mf1);
 			return 4;
