@@ -106,6 +106,16 @@ int main(int argc, char *argv[]) {
 			fprintf(stderr, "OK\n");
 		}
 
+		fprintf(stderr, "Running RBIN  test : %d ... ", i);
+		if (xdlt_auto_rabinregress(size, rmod, chmax) < 0) {
+
+			fprintf(stderr, "FAIL\n");
+			break;
+		} else {
+
+			fprintf(stderr, "OK\n");
+		}
+
 		fprintf(stderr, "Running MBIN  test : %d ... ", i);
 		if (xdlt_auto_mbinregress(&bdp, size, rmod, chmax, 32) != 0) {
 
