@@ -42,10 +42,13 @@ int xdlt_change_file(mmfile_t *mfo, mmfile_t *mfr, double rmod, int chmax);
 int xdlt_auto_regress(xpparam_t const *xpp, xdemitconf_t const *xecfg, long size,
 		      double rmod, int chmax);
 int xdlt_do_bindiff(mmfile_t *mf1, mmfile_t *mf2, bdiffparam_t const *bdp, mmfile_t *mfp);
+int xdlt_do_rabdiff(mmfile_t *mf1, mmfile_t *mf2, mmfile_t *mfp);
 int xdlt_do_binpatch(mmfile_t *mf, mmfile_t *mfp, mmfile_t *mfr);
 int xdlt_do_binregress(mmfile_t *mf1, mmfile_t *mf2, bdiffparam_t const *bdp);
+int xdlt_do_rabinregress(mmfile_t *mf1, mmfile_t *mf2);
 int xdlt_auto_binregress(bdiffparam_t const *bdp, long size,
 			 double rmod, int chmax);
+int xdlt_auto_rabinregress(long size, double rmod, int chmax);
 int xdlt_auto_mbinregress(bdiffparam_t const *bdp, long size,
 			  double rmod, int chmax, int n);
 
