@@ -23,13 +23,6 @@
 #include "xinclude.h"
 
 
-
-#define XDL_MIN_BLKSIZE 16
-#define XDL_INSBOP_SIZE (1 + 4)
-#define XDL_COPYOP_SIZE (1 + 4 + 4)
-
-
-
 typedef struct s_bdrecord {
 	struct s_bdrecord *next;
 	unsigned long fp;
@@ -45,13 +38,6 @@ typedef struct s_bdfile {
 
 
 
-
-static int xdl_prepare_bdfile(mmbuffer_t *mmb, long fpbsize, bdfile_t *bdf);
-static void xdl_free_bdfile(bdfile_t *bdf);
-
-
-
-
 static int xdl_prepare_bdfile(mmbuffer_t *mmb, long fpbsize, bdfile_t *bdf) {
 	unsigned int fphbits;
 	long i, size, hsize;
